SciSalt
=======

This project has slowly grown from frequently-used code snippets. The
main objective is to create a collection of interconnected methods
frequently needed to visualize and analyze data using Numpy, Scipy,
Matplotlib, and PyQt.

It is broken down into sections, with a large main section where most
everything is kept. It probably should be organized better, but that
could break backwards compatibility. Organization will probably happen
if and/or when the package is officially used by >1 person.
